@@ -188,7 +188,7 @@ int read_config()
 {
   FILE *config;
   struct bbs *bbs;
-  char s[256],*port=NULL;
+  char s[256],port[16],path[64],*addr;
   int i,j;
 
   if(!(config=fopen(CONFIG,"r"))) return(0);;
@@ -198,15 +198,14 @@ int read_config()
       bbs=(struct bbs *)malloc(sizeof(struct bbs));
       memset(bbs,0,sizeof(struct bbs));
       // otestuj pamet
-      i=sscanf(s,"%d %d %as %a[^\r\n]",&(bbs->resptime),&(bbs->waittime),
-               &port,&(bbs->path));
+      i=sscanf(s,"%d %d %16s %64[^\r\n]",&(bbs->resptime),&(bbs->waittime),port,path);
       if(i!=4){
-        free(bbs->port);
-	free(bbs->path);
 	free(bbs);
       }else{
-        bbs->port=ax25_config_get_addr(port);
-	free(port);
+        addr=ax25_config_get_addr(port);
+        if (addr!=NULL)
+          bbs->port=strdup(addr);
+        bbs->path=strdup(path);
 	first_call(s,bbs->path);
 	bbs->call=strdup(normalize_call(s));
 	bbs->enabled=1;
